@@ -1,7 +1,9 @@
 from vortex.handler.TupleActionProcessor import TupleActionProcessor
 
 from peek_plugin_diagram_trace._private.PluginNames import diagramTraceFilt
-from peek_plugin_diagram_trace._private.PluginNames import diagramTraceActionProcessorName
+from peek_plugin_diagram_trace._private.PluginNames import (
+    diagramTraceActionProcessorName,
+)
 from .controller.MainController import MainController
 
 
@@ -9,5 +11,6 @@ def makeTupleActionProcessorHandler(mainController: MainController):
     processor = TupleActionProcessor(
         tupleActionProcessorName=diagramTraceActionProcessorName,
         additionalFilt=diagramTraceFilt,
-        defaultDelegate=mainController)
+        defaultDelegate=mainController,
+    )
     return processor
